@extends('layouts.app')

@section('content')

<style>
    .half-donut .label {
      font-size: 3rem;
    }
    .donut-chart-svg {
    }
    .donut-chart-legend {
      font-family: 'Open Sans', sans-serif;
    }
    /* legend */
    .legend {
      font-size: 14px;
    }
    rect {
      cursor: pointer; 
      stroke-width: 2;
    }
    rect.disabled {
      fill: transparent !important;
    }

    /* chart */
    #detail-donut {
      height: 800px;
      margin: 0 auto;
      position: relative;
      display: block;
      width: 800px; 
    }

</style>
<a href='{{ action('MarkController@timeline', ["period" => 3600]) }}'
           class='btn btn-primary'>
            <i class="fas fa-expand"></i> Test
</a>
<div class="container-fluid" id="container">
    <div class="row">
        <div class="col-12 card" id="timeline" style="justify-content: center; align-items: center;">

        </div>
    </div>
    <div class="row">
        <div class="col-4 card">
            <h4 class="card-header text-center">RawData Entries</h4>
            <div class="card-body justify-content-center text-center" id="data-donut"></div>
        </div>
        <div class="col-4 card">
            <h4 class="card-header text-center">Evidence Entries</h4>
            <div class="card-body justify-content-center text-center" id="evidence-donut"></div>
        </div>
        <div class="col-4 card">
            <h4 class="card-header text-center">Evidence per Agent
            <button id="donut-button" class="btn btn-primary btn-sm" >Show Detailed View</button>
            </h4>
            <div class="card-body justify-content-center text-center" id="evidence-count">
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-12 card" id="evidence-count-big" style="display: none; justify-content: center; align-items: center;">
            <h4> Total Evidences Selected Count: <span class="new-total-holder"></span> </h4>
            <p class="font">Uncheck categories to recalculate.</p>
            <div id="detail-donut"></div>
        </div>
    </div>
    <div class="row vh-50">
        <div class="col-sm-auto col-md-auto col-lg-auto col-xl-auto card">
            <div class="card-body">
                <h3 class="card-title">Available Agents <i class="fas fa-info-circle"></i></h3>
                <table class="table">
                    @foreach ($graph_elements as $graph_element)
                    @php
                        $name = $graph_element["name"];
                    @endphp
                    <tr>
                        <td>
                            <button id="{{ $name }}"
                            class="btn btn-primary btn-sm">
                                {{ $name }}
                            </button>
<!--                            <a href="/app/ranking/{{ $name }}"
                            class="btn btn-secondary btn-sm"> -->
                            <button id="{{ $name }}_search" class="btn btn-secondary btn-sm">
                                <i class="fas fa-search"></i>
                            </button>
<!--                            </a> -->
                        </td>
                    </tr>
                    @endforeach
                </table>
            </div>
        </div>
        <div class="col card" id="visualization"></div>
    </div>
</div>

<div class="text-muted bottom-right">
    Reload visualization in <span id="reload-countdown">300</span> seconds
</div>

<script type="text/javascript">
    //Initialize the RawData/Evidence/EvidencesPerAgent visualizations
    var rawdata_container = document.getElementById("data-donut");
    var evidence_container = document.getElementById("evidence-donut");
    var evidence_count = document.getElementById("evidence-count");
    var detail_evidence_count = document.getElementById("detail-donut");
    var agents = @json($graph_elements);
    var agents_data = [];
    console.log(agents);
    agents.forEach(function (arrayItem){
        var name = arrayItem.name;
        agents_data.push({value:50, label: name});
    })
    agents_data.push({value:10, label: "detection.frequency"});
    agents_data.push({value:100, label: "detection.geooutlier"});
    window.addEventListener('DOMContentLoaded', function() {
        //get the dbstatus data
        var url = "/app/dbstatus";
        var request = $.get(url);
        
        request.done(function(response) {
            //when the request is done, load the half-donut visualizations
            drawHalfDonut(response["db.data.count"], 1000000, rawdata_container);
            drawHalfDonut(response["db.evidence.count"], 1000000, evidence_container);
            //create the button to show/hide the detailed evidences per agent donut visualization
            var donut_button = document.getElementById("donut-button");
            $("#donut-button").click(function() {
                $(this).toggleClass('btn-primary btn-secondary');
                $("#evidence-count-big").toggle();
                $(this).text(function(i, text) {
                    return text === "Hide" ? "Show Detailed View" : "Hide"; 
                });
            });
            //create the small evidences per agent donut visualization
            new SimpleDonut({
                element: evidence_count,
                width: 700,
                height: 200,
                data: agents_data
            });
            DetailDonut(agents_data, detail_evidence_count);
        });
        @include('scripts.half-donut-script')
        @include('scripts.simple-donut-script')
        @include('scripts.detail-donut-script');
    });
</script>

<script type="text/javascript">
    var json_elements = @json($graph_elements);
    var container = document.getElementById("visualization");
    //keep the ID of the interval function set for the refresh time
    var refresh_interval_id = 0;

    json_elements.forEach(function (arrayItem){
        var name = arrayItem.name;

        //add the EventListener to the Agent search button to display the rank listing
        var agent_search_name = name + "_search";
        document.getElementById(agent_search_name).addEventListener("click", function () {
            var ranking_url = "ranking/" + name;
            //load the html of a page into the given container
            load_ranking_html(container, ranking_url);
        })
        //add the EventListener to the Agent buttons for drawing the Bubble Graphs
        document.getElementById(name).addEventListener("click", function () {
            //clear the refreshing interval if a new bubble graph is drawn
            clearInterval(refresh_interval_id);
            var reload_countdown = 300;
            //draw the Bubble graph for the given agent in the given container
            drawBubbleGraph(name, container);
            //set the refresh interval
            var refresh = setInterval(function() {
                reload_countdown -= 1;
                $('#reload-countdown').text(reload_countdown);

                if (reload_countdown === 0) {
                    //console.log('reload...');
                    reload_countdown = 300;
                    drawBubbleGraph(name, container);
                }
            }, 1000);
            //save the ID of the refresh Interval, to be cleared if new bubble graph is drawn
            refresh_interval_id = refresh;
        });
    })

    async function load_ranking_html(container, url) {
        //d3.select(container).select("svg").remove();
        clearContent(container.id);
        var url_as_html = await fetchHtmlAsText(url);
        const document = new DOMParser().parseFromString(url_as_html, 'text/html');
        //remove the redundant bubble and radar buttons from the loaded document
        var fs_bubble_button = document.getElementById("fullscreen_bubble_button");
        fs_bubble_button.parentNode.removeChild(fs_bubble_button);
        var fs_radar_button = document.getElementById("fullscreen_radar_button");
        fs_radar_button.parentNode.removeChild(fs_radar_button);
        //get the main part of the HTML and set it to the innerHTML of the container
        const main = document.getElementsByTagName("main")[0];
        //console.log(main);
        container.innerHTML = main.innerHTML;
    }

    async function fetchHtmlAsText(url) {
        const response = await fetch(url);
        return await response.text();
    }

    function clearContent(elementID) {
        var div = document.getElementById(elementID);

        while(div.firstChild) {
            div.removeChild(div.lastChild);
        }
    }

    @include('scripts.bubble-script')
</script>

@endsection